package com.ruoyi.nanjing.service;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import com.ruoyi.nanjing.domain.ParaAllShow;
import com.ruoyi.nanjing.domain.ProRpList;
import com.ruoyi.nanjing.domain.TSyTracestate;

/**
 * traceStateService接口
 * 
 * @author limy
 * @date 2021-01-29
 */
public interface ITSyTracestateService 
{
    /**
     * 查询traceState
     * 
     * @param barcode traceStateID
     * @return traceState
     */
    public TSyTracestate selectTSyTracestateById(String barcode);

    /**
     * 查询traceState列表
     * 
     * @param tSyTracestate traceState
     * @return traceState集合
     */
    public List<TSyTracestate> selectTSyTracestateList(TSyTracestate tSyTracestate);

    /**
     * 新增traceState
     * 
     * @param tSyTracestate traceState
     * @return 结果
     */
    public int insertTSyTracestate(TSyTracestate tSyTracestate);

    /**
     * 修改traceState
     * 
     * @param tSyTracestate traceState
     * @return 结果
     */
    public int updateTSyTracestate(TSyTracestate tSyTracestate);

    /**
     * 批量删除traceState
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteTSyTracestateByIds(String ids);

    /**
     * 删除traceState信息
     * 
     * @param barcode traceStateID
     * @return 结果
     */
    public int deleteTSyTracestateById(String barcode);

    List<List<HashMap<String,String>>> selectAllPara(Map map);

    List selectStationPara(Map map);
}
